-- Instalacion de GONG-CM Base de datos para Cuadro de Mando de GONG


SET FOREIGN_KEY_CHECKS = 0;



USE gong_cm;


--
-- Table structure for table `log`
--

DROP TABLE IF EXISTS `log`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `log` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `tipo` varchar(1) COLLATE utf8_spanish_ci NOT NULL,
  `fecha_hora` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `Mensaje` varchar(255) COLLATE utf8_spanish_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COLLATE=utf8_spanish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;



SET FOREIGN_KEY_CHECKS = 1;

--
-- Dumping routines for database 'gong_cm'
--
DROP PROCEDURE IF EXISTS `carga_dimensiones`;
DELIMITER ;;
CREATE PROCEDURE `carga_dimensiones`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER

BEGIN
INSERT INTO log (tipo,mensaje) VALUES ('I', 'Comienza la actualización de dimensiones');
CALL carga_dim_area_actuacion(bdname);
CALL carga_dim_estado(bdname);
CALL carga_dim_moneda(bdname);
CALL carga_dim_financiador(bdname);
CALL carga_dim_implementador(bdname);
CALL carga_dim_pais(bdname);
CALL carga_dim_partida(bdname);
CALL carga_dim_periodo(bdname);
CALL carga_dim_proyecto_economico(bdname);
CALL carga_dim_proyecto_tecnico(bdname);
CALL carga_dim_sector_intervencion(bdname);
CALL carga_dim_sector_poblacion(bdname);
INSERT INTO log (tipo,mensaje) VALUES ('I', 'Finaliza la actualización de dimensiones');
END
 ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_area_actuacion`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_area_actuacion`(IN `bdname` varchar(50))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_area_actuacion');
	DROP TABLE IF EXISTS dim_area_actuacion;
	
	CREATE TABLE dim_area_actuacion
	(
	area_actuacion_id INT NOT NULL,
	area_actuacion VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_area_actuacion SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.area_actuacion;');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_area_actuacion');

END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_estado`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_estado`(IN `bdname` varchar(50))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_estado');
	DROP TABLE IF EXISTS dim_estado;

	CREATE TABLE dim_estado
	(
	estado_id INT NOT NULL,
	estado VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_estado SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.definicion_estado;');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_estado');

END
 ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_etiqueta_tecnica`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_etiqueta_tecnica`(IN `bdname` varchar(50))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_etiqueta_tecnica');
	DROP TABLE IF EXISTS dim_etiqueta_tecnica;
	
	CREATE TABLE dim_etiqueta_tecnica
	(
	etiqueta_tecnica_id INT NOT NULL,
	etiqueta_tecnica VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_etiqueta_tecnica SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.etiqueta_tecnica;');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_etiqueta_tecnica');

END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_financiador`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_financiador`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_financiador');
	DROP TABLE IF EXISTS dim_financiador;
	CREATE TABLE dim_financiador
	(
	financiador_id INT NOT NULL,
	financiador VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_financiador SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.agente WHERE financiador=1;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_financiador');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_implementador`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_implementador`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_implementador');
	DROP TABLE IF EXISTS dim_implementador;
	CREATE TABLE dim_implementador
	(
	implementador_id INT NOT NULL,
	implementador VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_implementador SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.agente WHERE implementador=1;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_implementador');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_moneda`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_moneda`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_moneda');
	DROP TABLE IF EXISTS dim_moneda;
	CREATE TABLE dim_moneda
	(
	moneda_id INT NOT NULL,
	moneda VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_moneda SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.moneda;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_moneda');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_pais`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_pais`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_pais');
	DROP TABLE IF EXISTS dim_pais;
	CREATE TABLE dim_pais
	(
	pais_id INT NOT NULL,
	pais VARCHAR (150) NOT NULL,
	area_geografica VARCHAR (150)
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_pais SELECT p.id, CONCAT( UCASE(LEFT(p.nombre, 1)) , SUBSTRING(p.nombre FROM 2) ), CONCAT( UCASE(LEFT(ag.nombre, 1)) , SUBSTRING(ag.nombre FROM 2) ) FROM ', @bdname , '.pais p left join ', @bdname , '.area_geografica ag on p.area_geografica_id= ag.id');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_pais');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_partida`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_partida`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_partida');
	DROP TABLE IF EXISTS dim_partida;
	CREATE TABLE dim_partida
	(
	partida_id INT NOT NULL,
	partida VARCHAR (150) NOT NULL,
	tipo VARCHAR (150)
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_partida SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ), CONCAT( UCASE(LEFT(tipo, 1)) , SUBSTRING(tipo FROM 2) ) FROM ', @bdname , '.partida;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_partida');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_periodo`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_periodo`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_periodo');
	DROP TABLE IF EXISTS dim_periodo;
	CREATE TABLE dim_periodo
	(
	periodo_id INT NOT NULL,
	ano VARCHAR (10) NOT NULL,
	mes VARCHAR (20) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_periodo SELECT DISTINCT periodo_id, ano, mes FROM
(
SELECT
	YEAR(p.fecha) * 100 + MONTH(p.fecha) AS periodo_id,
	YEAR(p.fecha) as ano, 
	MONTHNAME(p.fecha)  as mes
FROM 
	(
	SELECT DISTINCT pd.fecha_inicio as fecha
	FROM ', @bdname , '.presupuesto_detallado pd
	UNION
	SELECT DISTINCT g.fecha as fecha
	FROM ', @bdname , '.gasto g
	) as p
) as periodos
ORDER BY periodo_id;');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_periodo');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_proyecto_economico`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_proyecto_economico`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER

BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_proyecto_economico');
	DROP TABLE IF EXISTS dim_proyecto_economico;
	CREATE TABLE dim_proyecto_economico
	(
	proyecto_id INT NOT NULL,
	proyecto VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_proyecto_economico SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.proyecto where convenio_accion is null;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_proyecto_economico');
END
 ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_proyecto_tecnico`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_proyecto_tecnico`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER

BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_proyecto_tecnico');
	DROP TABLE IF EXISTS dim_proyecto_tecnico;
	CREATE TABLE dim_proyecto_tecnico
	(
	proyecto_id INT NOT NULL,
	proyecto VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_proyecto_tecnico SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.proyecto where convenio_id is null;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_proyecto_tecnico');
END
 ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_sector_intervencion`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_sector_intervencion`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_sector_intervencion');
	DROP TABLE IF EXISTS dim_sector_intervencion;
	CREATE TABLE dim_sector_intervencion
	(
	sector_intervencion_id INT NOT NULL,
	sector_intervencion VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_sector_intervencion SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.sector_intervencion;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_sector_intervencion');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_dim_sector_poblacion`;
DELIMITER ;;
CREATE PROCEDURE `carga_dim_sector_poblacion`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
	INSERT INTO log (tipo, mensaje) VALUES ('I','Comienza la actualización de la dimension dim_sector_poblacion');
	DROP TABLE IF EXISTS dim_sector_poblacion;
	CREATE TABLE dim_sector_poblacion
	(
	sector_poblacion_id INT NOT NULL,
	sector_poblacion VARCHAR (150) NOT NULL
	) ENGINE=InnoDB DEFAULT CHARSET=utf8;

	SET @bdname = bdname;
	SET @StringSQL = CONCAT( 'INSERT INTO dim_sector_poblacion SELECT id, CONCAT( UCASE(LEFT(nombre, 1)) , SUBSTRING(nombre FROM 2) ) FROM ', @bdname , '.sector_poblacion;');
	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;
	INSERT INTO log (tipo, mensaje) VALUES ('I','Finaliza la actualización de la dimension dim_sector_poblacion');
END ;;
DELIMITER ;

DROP PROCEDURE IF EXISTS `carga_hechos_economico`;
DELIMITER ;;
CREATE PROCEDURE `carga_hechos_economico`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN

        INSERT INTO log (tipo,mensaje) VALUES ('I', 'Comienza la actualización de hechos_economico');
        DROP TABLE IF EXISTS hechos_economico;

        CREATE TABLE `hechos_economico` (
          `financiador_id` int(11) DEFAULT NULL,
          `implementador_id` int(11) DEFAULT NULL,
          `moneda_id` int(11) DEFAULT NULL,
          `pais_id` int(11) DEFAULT NULL,
          `partida_id` int(11) DEFAULT NULL,
          `periodo_id` int(11) DEFAULT NULL,
          `proyecto_id` int(11) DEFAULT NULL,
          `presupuesto` decimal(10,2) DEFAULT '0.00',
          `gasto` decimal(10,2) DEFAULT '0.00'
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


        SET @bdname = bdname;

  SET @StringSQL = CONCAT(
  'INSERT INTO hechos_economico (
    financiador_id,
    implementador_id,
    moneda_id,
    pais_id, 
    partida_id, 
    periodo_id, 
    proyecto_id,
    presupuesto,
    gasto   
    )
SELECT 
financiador_id,
implementador_id,
moneda_id,
pais_id,
partida_id,
periodo_id,
proyecto_id,
SUM(presupuesto),
SUM(gasto)

FROM
  (

  SELECT 
    -- ga.agente_id as financiador_id,
    NULL as financiador_id,
    g.agente_id as implementador_id,
    g.moneda_id as moneda_id,
    ag.pais_id as pais_id,
    g.partida_id as partida_id,
    YEAR(g.fecha) *100 + MONTH(g.fecha)  as periodo_id,
    -- g.fecha as periodo_id, 
    proyecto_origen_id as proyecto_id,
    -- ga.importe as gasto_original,
    -- tc.tasa_cambio,
    0 as presupuesto,
    --ROUND(ga.importe * tc.tasa_cambio,2) as gasto
    -- Eliminar la multiplicacion por tasa de cabmio para que el dato esté en la moneda original.
    ROUND(ga.importe,2) as gasto

  FROM 
    ', @bdname,'.gasto g
    INNER JOIN
    ', @bdname,'.gasto_x_agente ga
    ON g.id = ga.gasto_id AND ga.proyecto_id = g.proyecto_origen_id 
    INNER JOIN 
    ', @bdname,'.gasto_x_proyecto gp
    ON gp.proyecto_id = g.proyecto_origen_id AND gp.gasto_id = g.id
    INNER JOIN
    ', @bdname,'.tasa_cambio tc
    ON tc.id = gp.tasa_cambio_id
    INNER JOIN 
    ', @bdname,'.agente ag
    ON ga.agente_id=ag.id


  UNION


  SELECT 
    pa.agente_id as financiador_id,
    p.agente_id as implementador_id,
    p.moneda_id AS moneda_id,
    ag.pais_id AS pais_id,
    p.partida_id AS partida_id,
    YEAR(pd.fecha_inicio) *100 + MONTH(pd.fecha_inicio)  as periodo_id,
    p.proyecto_id AS proyecto_id,
    -- pd.importe * pa.importe / p.importe  as importe_original,
    -- tc.tasa_cambio,
    -- ROUND(pd.importe * pa.importe / p.importe * tc.tasa_cambio,2) AS presupuesto,
    ROUND(pd.importe * pa.importe / p.importe,2) AS presupuesto,
	-- Eliminar la tasa de cambio para que el dato este en su moneda original.
    0 as gasto

  FROM 
    ', @bdname,'.presupuesto p
    INNER JOIN
    ', @bdname,'.presupuesto_detallado pd
    ON p.id = pd.presupuesto_id
    INNER JOIN 
    ', @bdname,'.presupuesto_x_agente pa
    ON pa.presupuesto_id = p.id
    INNER JOIN
    ', @bdname,'.tasa_cambio tc
    ON tc.id = p.tasa_cambio_id
    INNER JOIN
    ', @bdname,'.agente ag
    ON ag.id = pa.agente_id

  ) as datos

WHERE
  proyecto_id NOT IN (select distinct id from ', @bdname, '.proyecto where convenio_accion is not null)

GROUP BY 
financiador_id,
implementador_id,
moneda_id,
pais_id,
partida_id,
periodo_id,
proyecto_id
');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;

	INSERT INTO log (tipo,mensaje) VALUES ('I', 'Finaliza la actualización de hechos_economico');

END ;;
DELIMITER ;


DROP PROCEDURE IF EXISTS `carga_hechos_tecnico`;
DELIMITER ;;
CREATE PROCEDURE `carga_hechos_tecnico`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER

BEGIN

        INSERT INTO log (tipo,mensaje) VALUES ('I', 'Comienza la actualización de hechos_tecnico');
        DROP TABLE IF EXISTS hechos_tecnico;

        CREATE TABLE `hechos_tecnico` (
          `financiador_id` int(11) DEFAULT NULL,
          `implementador_id` int(11) DEFAULT NULL,
          `moneda_id` int(11) DEFAULT NULL,
          `pais_id` int(11) DEFAULT NULL,
          `periodo_id` int(11) DEFAULT NULL,
          `proyecto_id` int(11) DEFAULT NULL
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


        SET @bdname = bdname;

  SET @StringSQL = CONCAT(
  'INSERT INTO hechos_tecnico (
    financiador_id,
    implementador_id,
    moneda_id,
    pais_id, 
    periodo_id, 
    proyecto_id
    )
    
SELECT 
financiador_id,
implementador_id,
moneda_id,
pais_id,
periodo_id,
proyecto_id

FROM
  (
  SELECT 
    pa.agente_id as financiador_id,
    p.agente_id as implementador_id,
    p.moneda_id AS moneda_id,
    ag.pais_id AS pais_id,
    YEAR(pd.fecha_inicio) *100 + MONTH(pd.fecha_inicio)  as periodo_id,
    p.proyecto_id AS proyecto_id
    
  FROM 
    gor_dev.presupuesto p
    INNER JOIN
    gor_dev.presupuesto_x_agente pa
    ON pa.presupuesto_id = p.id
    INNER JOIN 
    gor_dev.presupuesto_detallado pd
    ON p.id = pd.presupuesto_id
    INNER JOIN
    gor_dev.agente ag
    ON ag.id = pa.agente_id
    INNER JOIN
    gor_dev.proyecto pro
    ON pro.id = p.proyecto_id

WHERE
  pro.convenio_id is null

  ) as datos

GROUP BY 
financiador_id,
implementador_id,
moneda_id,
pais_id,
periodo_id,
proyecto_id

');

	PREPARE instruccion FROM @StringSQL;
	EXECUTE instruccion;
	DEALLOCATE PREPARE instruccion;

	INSERT INTO log (tipo,mensaje) VALUES ('I', 'Finaliza la actualización de hechos_tecnico');

END;;

DELIMITER ;


DROP PROCEDURE IF EXISTS `carga_todo`;
DELIMITER ;;
CREATE PROCEDURE `carga_todo`(IN `bdname` varchar(32))
    SQL SECURITY INVOKER
BEGIN
  INSERT INTO log (tipo,mensaje) VALUES ('I', '************************************');
  INSERT INTO log (tipo,mensaje) VALUES ('I', 'Comienza el proceso de actualización');
  CALL carga_dimensiones(bdname);
  CALL carga_hechos_economico(bdname);
  CALL carga_hechos_tecnico(bdname);
  INSERT INTO log (tipo,mensaje) VALUES ('I', 'Termina el proceso de actualización');
  COMMIT;
END ;;
DELIMITER ;

